@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::XMLReader;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::XMLReader::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.34.4');
+use version; our $VERSION = qv('v0.34.6');
 
 use 5.010;
 use Moose;
@@ -30,6 +30,7 @@ has file =>(
 		predicate	=> 'has_file',
 		clearer		=> 'clear_file',
 		coerce		=> 1,
+		required	=> 1,
 		trigger		=> \&_build_xml_reader,
 	);
 
@@ -75,30 +76,17 @@ has _xml_reader =>(
 		copy_current_node	=> 'copyCurrentNode',
 		byte_consumed		=> 'byteConsumed',
 		start_reading		=> 'read',
-		next_node			=> 'next',
 		next_element		=> 'nextElement',
-		next_sibling		=> 'nextSibling',
-		get_attribute		=> 'getAttribute',
-		read_state			=> 'readState',
 		node_type			=> 'nodeType',
-		text_content		=> 'textContent',
 		node_name			=> 'name',
 		node_value			=> 'value',
 		has_value			=> 'hasValue',
-		inner_xml			=> 'readInnerXml',
 		node_depth			=> 'depth',
-		is_empty			=> 'isEmptyElement',
-		inner_xml			=> 'readInnerXml',
-		has_attributes		=> 'hasAttributes',
-		get_attribute_count	=> 'attributeCount',
-		read_attribute		=> 'readAttributeValue',
-		constant_value		=> 'ConstValue',
 		move_to_first_att	=> 'moveToFirstAttribute',
 		move_to_next_att	=> 'moveToNextAttribute',
 		encoding			=> 'encoding',
 		_go_to_the_end		=> 'finish',
 		_close_the_sheet	=> 'close',
-		next_sibling_element	=> 'nextSiblingElement',
 	},
 	trigger => \&_reader_init,
 );
@@ -208,18 +196,222 @@ Spreadsheet::XLSX::Reader::LibXML::XMLReader - A LibXML::Reader xlsx base class
     
 =head1 DESCRIPTION
 
-B<This documentation is written to explain ways to extend this package.  To use the data 
-extraction of Excel workbooks, worksheets, and cells please review the documentation for  
-L<Spreadsheet::XLSX::Reader::LibXML>,
-L<Spreadsheet::XLSX::Reader::LibXML::Worksheet>, and 
-L<Spreadsheet::XLSX::Reader::LibXML::Cell>>
+This documentation is written to explain ways to use this module when writing your own excel 
+parser.  To use the general package for excel parsing out of the box please review the 
+documentation for L<Workbooks|Spreadsheet::XLSX::Reader::LibXML>,
+L<Worksheets|Spreadsheet::XLSX::Reader::LibXML::Worksheet>, and 
+L<Cells|Spreadsheet::XLSX::Reader::LibXML::Cell>
 
-When setting worksheet file handles you can't reuse them again to re-open the same sheet 
-since the last act of this package is to close the file handle before returning it.  You 
-must also set both the file handle and the xml reader when building an instance of this 
-class.
+This module provides a generic way to open an xml file or xml file handle and then extract 
+information using the L<XML::LibXML::Reader> parser.  The class does this by using 
+L<delegation|Moose::Manual::Delegation> from the ~::Reader module to import useful functions 
+to this module.  Aside from the delegation piece this module provides four other useful 
+elements.  First, the module has an attribute to load the file or file handle and uses coercion 
+to turn a file into a file handle from the L<Types
+|Spreadsheet::XLSX::Reader::LibXML::Types/IOFileType> library.  Second, the module has an 
+attribute to store an L<error handler|Spreadsheet::XLSX::Reader::LibXML::Error>.  Third, 
+the module provides a L<rewind|/start_the_file_over> function since that is not available in  
+the L<XML::LibXML::Reader> parser. Finally, this module has a hook for classes that extend 
+this functionality during the initial build.  The initialization of the file will also attempt 
+to call '_load_unique_bits'.  It will only call that method once on initialization.
 
-POD not written yet!
+Further use of the module or specialization of the reader can be done by L<extending|/SYNOPSIS> 
+the class.
+
+=head2 Attributes
+
+Data passed to new when creating an instance.  For modification of these attributes see the 
+listed 'attribute methods'. For general information on attributes see 
+L<Moose::Manual::Attributes>.  For ways to manage the instance when opened see the 
+L<Methods|/Methods>.
+
+=head3 file
+
+=over
+
+B<Definition:> This attribute holds the file handle for the file being read.  If the full 
+file name and path is passed to the attribute it is coerced to an IO::File file handle.
+
+B<Default:> no default - this must be provided to read a file
+
+B<Required:> yes
+
+B<Range:> any unencrypted xml file name and path or file handle
+
+B<attribute methods> Methods provided to adjust this attribute
+		
+=over
+
+B<set_file>
+
+=over
+
+B<Definition:> change the file value in the attribute (this will reboot 
+the file instance and lock the file)
+
+=back
+
+B<get_file>
+
+=over
+
+B<Definition:> Returns the file handle of the file even if a file name 
+was passed
+
+=back
+
+B<has_file>
+
+=over
+
+B<Definition:> this is used to see if the file loaded correctly.
+
+=back
+
+B<clear_file>
+
+=over
+
+B<Definition:> this clears (and unlocks) the file handle
+
+=back
+
+=back
+
+=back
+
+=head3 error_inst
+
+=over
+
+B<Definition:> This attribute holds the L<error handler
+|Spreadsheet::XLSX::Reader::LibXML::Error>.
+
+B<Default:> no default - this must be provided to read a file
+
+B<Required:> yes
+
+B<Range:> any object instance that can provide the required delegated methods.
+
+B<delegated methods> Methods provided delegated by the attribute
+		
+=over
+
+B<error>
+
+=over
+
+B<Definition:> returns the stored error string
+
+=back
+
+B<set_error>
+
+=over
+
+B<Definition:> Sets the error string
+
+=back
+
+B<clear_error>
+
+=over
+
+B<Definition:> clears the error string
+
+=back
+
+B<set_warnings>
+
+=over
+
+B<Definition:> Sets the state that determins if the instance pro-activly 
+warns with the error string when the error string is set.
+
+=back
+
+B<if_warn>
+
+=over
+
+B<Definition:> Returns the current state of the state value from 'set_warnings'
+
+=back
+
+=back
+
+=back
+
+=head2 Class Methods
+
+These are the methods provided by this class.  They most likely should be agumented 
+with file specific methods when extending this module.
+
+=head3 start_the_file_over
+
+=over
+
+B<Definition:> This will disconnect the L<XML::LibXML::Reader> from the file handle,  
+rewind the file handle, and then reconnect the L<XML::LibXML::Reader> to the file handle.
+
+B<Accepts:> nothing
+
+B<Returns:> nothing
+
+=back
+
+=head2 Delegated Methods
+
+These are the methods delegated to this class from L<XML::LibXML::Reader>.  For more 
+general parsing of subsections of the xml file also see L<Spreadsheet::XLSX::Reader::LibXML>.
+
+=head3 copy_current_node
+
+B<Delegated from:> L<XML::LibXML::Reader/copyCurrentNode (deep)>
+
+=head3 byte_consumed
+
+B<Delegated from:> L<XML::LibXML::Reader/byteConsumed ()>
+
+=head3 start_reading
+
+B<Delegated from:> L<XML::LibXML::Reader/read ()>
+
+=head3 next_element
+
+B<Delegated from:> L<XML::LibXML::Reader/nextElement>
+
+=head3 node_type
+
+B<Delegated from:> L<XML::LibXML::Reader/nodeType>
+
+=head3 node_name
+
+B<Delegated from:> L<XML::LibXML::Reader/name>
+
+=head3 node_value
+
+B<Delegated from:> L<XML::LibXML::Reader/value>
+
+=head3 has_value
+
+B<Delegated from:> L<XML::LibXML::Reader/hasValue>
+
+=head3 node_depth
+
+B<Delegated from:> L<XML::LibXML::Reader/depth>
+
+=head3 move_to_first_att
+
+B<Delegated from:> L<XML::LibXML::Reader/moveToFirstAttribute>
+
+=head3 move_to_next_att
+
+B<Delegated from:> L<XML::LibXML::Reader/moveToNextAttribute>
+
+=head3 encoding
+
+B<Delegated from:> L<XML::LibXML::Reader/encoding ()>
 
 =head1 SUPPORT
 
@@ -234,7 +426,7 @@ L<github Spreadsheet::XLSX::Reader::LibXML/issues
 
 =over
 
-B<1.> Nothing L<yet|/SUPPORT>
+B<1.> Nothing currently
 
 =back
 
@@ -256,13 +448,13 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
-This software is copyrighted (c) 2014 by Jed Lund
+This software is copyrighted (c) 2014, 2015 by Jed Lund
 
 =head1 DEPENDENCIES
 
 =over
 
-L<Spreadsheet::XLSX::Reader::LibXML>
+L<XML::LibXML::Reader>
 
 =back
 
